<h1 align="center"> Site Cloner</h1>
<p align="center">A simple tool to clone a website</p>
<p align="center">This tool is for educational purposes only.Please follow the copyright 
    laws of your country. Our team is not responsible for any misuse.</p>

## Installation

```bash
git clone https://github.com/Py-Contributors/site-cloner
cd site-cloner
pip install -r requirements.txt
```

## Usage

```python
from site_cloner import SiteCloner

sc = SiteCloner("https://codeperfectplus.herokuapp.com/")
sc.clone_website()
```

## Upcoming Features

- [x] Add Support for download multiple pages(v1.0.0)
- [x] Add Support for downloading images(v1.0.0)\
- [x] Pip Package Support
- [ ] Add support for cloning websites with login


## Changelog

**0.0.1**

- [x] Initial Release
- [x] Implemented basic functionality
- [x] Implemented downloading of images
- [x] Implemented downloading of multiple pages
- [x] Pip Package Support


## Contributors

<a href="https://github.com/Py-Contributors/site-cloner/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=Py-Contributors/site-cloner" />
</a>

